@@ -56,13 +56,13 @@ VERSION_MANIFEST=$(cat "manifests/${VERSION}.json")
 # 1.12 and earlier, natives and regular libraries are contained in different elements. For 1.13 and later, an element may contain both.
 CLASSPATH=
 for I in $(echo "${VERSION_MANIFEST}" | jq -c .libraries.[]); do
-	if [[ $(echo "${I}" | jq .downloads.artifact) != 'null' ]]; then
+	if [ "$(echo "${I}" | jq .downloads.artifact)" != 'null' ]; then
 		for J in ${BLACKLISTED_LIBRARIES}; do
 			if [ ${J} == $(basename $(echo ${I} | jq -r .downloads.artifact.path)) ]; then
 				SKIP=1
 			fi
 		done
-		if [[ ${SKIP} -eq 1 ]]; then
+		if [ "${SKIP}" = '1' ]; then
 			SKIP=
 			continue
 		fi
@@ -71,13 +71,13 @@ for I in $(echo "${VERSION_MANIFEST}" | jq -c .libraries.[]); do
 			CLASSPATH="${PWD}/libraries/${JAR}:${CLASSPATH}"
 		fi
 	fi
-	if [[ $(echo "${I}" | jq .natives) != 'null' ]]; then
+	if [ "$(echo "${I}" | jq .natives)" != 'null' ]; then
 		for J in ${BLACKLISTED_NATIVES}; do
 			if [ ${J} == $(basename $(echo ${I} | jq ".downloads.classifiers.\"natives-${PLATFORM}\".path")) ]; then
 				SKIP=1
 			fi
 		done
-		if [[ ${SKIP} -eq 1 ]]; then
+		if [ "${SKIP}" = '1' ]; then
 			SKIP=
 			continue
 		fi
@@ -94,7 +94,7 @@ done
 
 CLASSPATH="${CLASSPATH}:${PWD}/${MINECRAFT_JAR}"
 
-if [[ $(echo "${VERSION_MANIFEST}" | jq -r .minecraftArguments) != 'null' ]]; then
+if [ "$(echo "${VERSION_MANIFEST}" | jq -r .minecraftArguments)" != 'null' ]; then
 	ARGUMENT_LIST=$(echo ${VERSION_MANIFEST} | jq -r .minecraftArguments)
 else
 	for I in $(echo ${VERSION_MANIFEST} | jq -r '.arguments.game[] | select(type=="string")'); do
